==> byways-2.4.1.tgz: package/contents/byway/75227.md <==
---
id: "75227"
name: Great Salt Lake Legacy Parkway
distance: "14"
duration: "Allow 15 - 20 minutes to drive the byway."
description: "Meander through the grasslands and wetlands along the shores of the Great Salt Lake as you cruise one of the\r\nonly parkways designed in modern times. The design of the parkway maximizes views of the Great Salt Lake, Antelope\r\nIsland, and the majestic Wasatch Mountains while being sensitive to this incredible natural resource."
path: "mvdyFbf_jTdHyFfLaCdH}@lBk@|T}MtDcB|U{G`a@mKpWkIzEiA`CYdDY|EGt^r@`_@PvYW|Sa@fLElUZz\\JnAP`E`AvDvBxDtDrIzJzE`FnDbClDrAbB^hWzC`HjAxA`@zB~@nEfDlB`ChBdDnBxFlDnMtArEvBxE|BzDbCtCzBxBd[lYpIhJfGbIfEfGnCvF|DhJ|BlElDlGjTzVbNhPlHpHvCvB|G~CvI`DpI~BlDt@|F|@vKt@`Rp@bEVjo@lB|Fj@zJhFbUxNlKnG~DxA~Dj@bDDzbAcExd@g@nKe@`\\{FbCYfE?hEx@TJnBt@vCfBnLtMjLzH"
websites:
  - url: "https://www.fogsl.org/"
    name: Friends of Great Salt Lake
  - url: "https://greatsaltlakeaudubon.org/"
    name: Great Salt Lake Audubon
  - url: "https://www.daviscountyutah.gov/greatsaltlakebirdfest"
    name: Great Salt Lake Bird Festival
  - url: "https://greatsaltlakenaturecenter.org/"
    name: Great Salt Lake Nature Center
  - url: "https://www.thearmchairexplorer.com/utah/great-salt-lake-legacy-parkway.php"
    name: The Armchair Explorer
  - url: "https://whsrn.org/"
    name: Western Hemisphere Shorebird Reserve Network
designations:
  - Utah State Scenic Byway
states:
  - UT
ll:
  - -111.9038529779415
  - 40.989352695348664
bounds:
  - - -111.94665970148925
    - 40.82910212449205
  - - -111.89279199999999
    - 40.989352695348664

---

Meander through the grasslands and wetlands along the shores of the Great Salt Lake as you cruise one of the
only parkways designed in modern times. The design of the parkway maximizes views of the Great Salt Lake, Antelope
Island, and the majestic Wasatch Mountains while being sensitive to this incredible natural resource.

The hallmark of this scenic byway is the Great Salt Lake. It is the largest natural lake west of the Mississippi River and the largest salt lake in the western hemisphere. This scenic byway tells the fascinating story of the unique and sometimes bizarre biology, geomorphology, topography and natural history of the Great Salt Lake.

Take a 10-minute drive from downtown Salt Lake City or its international airport to enter this 14-mile parkway balanced onto a narrow stretch of land between the Wasatch Mountains and the Great Salt Lake. As you pass through the gateway feature announcing Legacy Parkway, notice how the road changes – speeds are slower, the roadway narrower and more winding, and there are few signs to distract you. Take a deep breath and take in the wide open views from the dramatic Wasatch Mountains to the vast open grasslands along the lake’s shores. Whether you are a first time visitor, or have lived along the Great Salt Lake your whole life, the peaceful drive unwinds you to open your eyes to the marvels at the road’s edge.

Enjoy hiking, biking and bird-watching in this vast wilderness, one of the world’s largest migratory bird flyways, with over 5 million avian visitors and residents each year. Head out on the Legacy Parkway Trail or visit the Farmington Bay Waterfowl Management Area for an unforgettable visit to the lake.

The Great Salt Lake is a richly diverse ecosystem, with fascinating aquatic life, but even more critically, some of the world’s most productive wetlands. 400,000 acres of wetlands around the lake create a locally, nationally, and globally significant habitat for nearly 5 million resident and migratory birds representing over 250 species. In recognition of its hemispheric importance, the Great Salt Lake was dedicated into the Western Hemisphere Shorebird Reserve Network in 1991, one of only eight such sites in the United States.

==> byways-2.4.7.tgz: package/contents/byway/75227.md <==
---
id: "75227"
name: Great Salt Lake Legacy Parkway
distance: "14"
duration: Allow 15 - 20 minutes to drive the byway.
description: "Meander through the grasslands and wetlands along the shores of the Great Salt Lake as you cruise one of the only parkways designed in modern times. The design of the parkway maximizes views of the Great Salt Lake, Antelope Island, and the majestic Wasatch Mountains while being sensitive to this incredible natural resource."
path: mvdyFbf_jTdHyFfLaCdH}@lBk@|T}MtDcB|U{G`a@mKpWkIzEiA`CYdDY|EGt^r@`_@PvYW|Sa@fLElUZz\JnAP`E`AvDvBxDtDrIzJzE`FnDbClDrAbB^hWzC`HjAxA`@zB~@nEfDlB`ChBdDnBxFlDnMtArEvBxE|BzDbCtCzBxBd[lYpIhJfGbIfEfGnCvF|DhJ|BlElDlGjTzVbNhPlHpHvCvB|G~CvI`DpI~BlDt@|F|@vKt@`Rp@bEVjo@lB|Fj@zJhFbUxNlKnG~DxA~Dj@bDDzbAcExd@g@nKe@`\{FbCYfE?hEx@TJnBt@vCfBnLtMjLzH
websites:
  - url: https://wildlife.utah.gov/eccles.html
    name: Eccles Wildlife Education Center
  - url: https://www.fogsl.org/
    name: Friends of Great Salt Lake
  - url: https://greatsaltlakeaudubon.org/
    name: Great Salt Lake Audubon
  - url: https://www.daviscountyutah.gov/greatsaltlakebirdfest
    name: Great Salt Lake Bird Festival
  - url: https://www.thearmchairexplorer.com/utah/great-salt-lake-legacy-parkway.php
    name: The Armchair Explorer
  - url: https://whsrn.org/
    name: Western Hemisphere Shorebird Reserve Network
designations:
  - Utah State Scenic Byway
states:
  - UT
ll:
  - -111.9038529779415
  - 40.989352695348664
bounds:
  - - -111.94665970148925
    - 40.82910212449205
  - - -111.89279199999999
    - 40.989352695348664

---

Meander through the grasslands and wetlands along the shores of the Great Salt Lake as you cruise one of the only parkways designed in modern times. The design of the parkway maximizes views of the Great Salt Lake, Antelope Island, and the majestic Wasatch Mountains while being sensitive to this incredible natural resource.

The hallmark of this scenic byway is the Great Salt Lake. It is the largest natural lake west of the Mississippi River and the largest salt lake in the western hemisphere. This scenic byway tells the fascinating story of the unique and sometimes bizarre biology, geomorphology, topography and natural history of the Great Salt Lake.

Take a 10-minute drive from downtown Salt Lake City or its international airport to enter this 14-mile parkway balanced onto a narrow stretch of land between the Wasatch Mountains and the Great Salt Lake. As you pass through the gateway feature announcing Legacy Parkway, notice how the road changes – speeds are slower, the roadway narrower and more winding, and there are few signs to distract you. Take a deep breath and take in the wide open views from the dramatic Wasatch Mountains to the vast open grasslands along the lake’s shores. Whether you are a first time visitor, or have lived along the Great Salt Lake your whole life, the peaceful drive unwinds you to open your eyes to the marvels at the road’s edge.

Enjoy hiking, biking and bird-watching in this vast wilderness, one of the world’s largest migratory bird flyways, with over 5 million avian visitors and residents each year. Head out on the Legacy Parkway Trail or visit the Farmington Bay Waterfowl Management Area for an unforgettable visit to the lake.

The Great Salt Lake is a richly diverse ecosystem, with fascinating aquatic life, but even more critically, some of the world’s most productive wetlands. 400,000 acres of wetlands around the lake create a locally, nationally, and globally significant habitat for nearly 5 million resident and migratory birds representing over 250 species. In recognition of its hemispheric importance, the Great Salt Lake was dedicated into the Western Hemisphere Shorebird Reserve Network in 1991, one of only eight such sites in the United States.
